@@ -10,10 +10,10 @@ import unittest
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 from test.helper import http_server_port, try_rm
-from youtube_dlc import YoutubeDL
-from youtube_dlc.compat import compat_http_server
-from youtube_dlc.downloader.http import HttpFD
-from youtube_dlc.utils import encodeFilename
+from yt_dlp import YoutubeDL
+from yt_dlp.compat import compat_http_server
+from yt_dlp.downloader.http import HttpFD
+from yt_dlp.utils import encodeFilename
 import threading
 
 TEST_DIR = os.path.dirname(os.path.abspath(__file__))
