@@ -246,7 +246,7 @@ class NPOIE(NPOBaseIE):
                 })
 
         if not formats:
-            if not self._downloader.params.get('allow_unplayable_formats') and drm:
+            if not self.get_param('allow_unplayable_formats') and drm:
                 self.raise_no_formats('This video is DRM protected.', expected=True)
             return
 
