@@ -200,7 +200,7 @@ class RuutuIE(InfoExtractor):
                 return node.get('value')
 
         if not formats:
-            if (not self._downloader.params.get('allow_unplayable_formats')
+            if (not self.get_param('allow_unplayable_formats')
                     and xpath_text(video_xml, './Clip/DRM', default=None)):
                 self.raise_no_formats('This video is DRM protected.', expected=True)
             ns_st_cds = pv('ns_st_cds')
