@@ -59,7 +59,7 @@ class TwitCastingIE(InfoExtractor):
     def _real_extract(self, url):
         uploader_id, video_id = re.match(self._VALID_URL, url).groups()
 
-        video_password = self._downloader.params.get('videopassword')
+        video_password = self.get_param('videopassword')
         request_data = None
         if video_password:
             request_data = urlencode_postdata({
