@@ -6,6 +6,7 @@ from .common import PostProcessor
 from ..compat import compat_shlex_split
 from ..utils import (
     check_executable,
+    cli_option,
     encodeArgument,
     encodeFilename,
     shell_quote,
@@ -31,7 +32,7 @@ class SponSkrubPP(PostProcessor):
             if path:
                 raise PostProcessingError('sponskrub not found in "%s"' % path)
             else:
-                raise PostProcessingError('sponskrub not found. Please install or provide the path using --sponskrub-path.')
+                raise PostProcessingError('sponskrub not found. Please install or provide the path using --sponskrub-path')
 
     def get_exe(self, path=''):
         if not path or not check_executable(path, ['-h']):
@@ -70,6 +71,7 @@ class SponSkrubPP(PostProcessor):
         cmd = [self.path]
         if not self.cutout:
             cmd += ['-chapter']
+        cmd += cli_option(self._downloader.params, '-proxy', 'proxy')
         cmd += compat_shlex_split(self.args)  # For backward compatibility
         cmd += self._configuration_args(self._exe_name, use_compat=False)
         cmd += ['--', information['id'], filename, temp_filename]
